==> punbb-1.3.tar.gz: punbb-1.3/lang/English/misc.php <==
<?php

// Language definitions used in various scripts
$lang_misc = array(

'Mark read redirect'		=>	'All topics and forums have been marked as read. Redirecting …',
'Mark forum read redirect'	=>	'All topics in the specified forum have been marked as read. Redirecting …',

// Send e-mail
'Form e-mail disabled'		=>	'The user you are trying to send an e-mail to has disabled form e-mail.',
'Form e-mail errors'		=>	'<strong>Warning!</strong> The following errors must be corrected before your message can be sent:',
'No e-mail subject'			=>	'You must enter a subject.',
'No e-mail message'			=>	'You must enter a message.',
'Too long e-mail message'	=>	'Your message length is %s bytes. This exceeds the %s bytes limit.',
'Email flood'				=>	'At least %s seconds have to pass between sent emails. Please wait a while and try sending again.',
'E-mail sent redirect'		=>	'E-mail sent. Redirecting …',
'E-mail subject'			=>	'Subject',
'E-mail message'			=>	'Message',
'E-mail disclosure note'	=>	'<strong>Important!</strong> When you send an e-mail using this form your e-mail address will be disclosed to the recipient.',
'Write e-mail'				=>	'Compose e-mail',
'Send forum e-mail'			=>	'Send e-mail to %s via the forum',

// Report
'No reason'					=>	'You must enter a reason.',
'Report flood'				=>	'At least %s seconds have to pass between reports. Please wait a while and try sending again.',
'Report redirect'			=>	'Post reported. Redirecting …',
'Report post'				=>	'Report post',
'Reason'					=>	'Reason',
'Reason help'				=>	'Enter a short reason why you are reporting this post.',

// Subscriptions
'Already subscribed'		=>	'You are already subscribed to this topic.',
'Subscribe redirect'		=>	'Your subscription has been added. Redirecting …',
'Not subscribed'			=>	'You are not subscribed to this topic.',
'Unsubscribe redirect'		=>	'Your subscription has been removed. Redirecting …',

// General forum and topic moderation
'Moderate forum'			=>	'Moderate forum',
'Select'					=>	'Select',	// the header of a column of checkboxes
'Move'						=>	'Move',
'Merge'						=>	'Merge',
'Open'						=>  'Open',
'Close'						=>  'Close',
'Select all'				=>	'Select all',


// Hostname lookup
'Hostname lookup'			=>	'The IP address is: %1$s<br />The host name is: %2$s<br /><br />%3$s',
'Show more users'			=>	'Show more users for this IP',

// Moderate forum
'Moderate forum head'		=>	'Moderate : %s',
'Topics'					=>	'Topics',
'Move topic'				=>	'Move topic',
'Move topics'				=>	'Move topics',
'Merge topics'				=>	'Merge topics',
'Delete topics'				=>	'Delete topics',
'Delete topic'				=>	'Delete topic',
'To new forum'				=>	'to a new forum',
'Move to'					=>	'Destination forum',
'Redirect topic'			=>	'Redirect setting',
'Nowhere to move'			=>	'There are no forums into which you can move topics.',
'Leave redirect'			=>	'Leave a redirect topic in the forum from which the topic was moved.',
'Leave redirects'			=>	'Leave redirect topics in the forum from which topics were moved.',
'Leave merge redirects'		=>	'Leave redirect topics for those topics which were merged.',
'Move topic redirect'		=>	'Topic moved. Redirecting …',
'Move topics redirect'		=>	'Topics moved. Redirecting …',
'Merge topics redirect'		=>	'Topics merged. Redirecting …',
'Delete topic comply'		=>	'Are you sure you want to delete the selected topic?',
'Delete topics comply'		=>	'Are you sure you want to delete all the selected topics?',
'Delete topic redirect'		=>	'Topic deleted. Redirecting …',
'Delete topics redirect'	=>	'Topics deleted. Redirecting …',
'Open topic redirect'		=>	'Topic opened. Redirecting …',
'Open topics redirect'		=>	'Topics opened. Redirecting …',
'Close topic redirect'		=>	'Topic closed. Redirecting …',
'Close topics redirect'		=>	'Topics closed. Redirecting …',
'No topics selected'		=>	'You must select at least one topic.',
'Stick topic redirect'		=>	'Topic is now sticky. Redirecting …',
'Unstick topic redirect'	=>	'Topic no longer sticky. Redirecting …',
'Merge error'				=>	'You should select more than 1 topic to merge.',

// Moderate topic
'Posts'						=>	'Posts',
'Delete posts'				=>	'Delete selected posts',
'Split posts'				=>	'Split selected posts',
'Delete whole topic'		=>	'Delete whole topic',
'Moderate topic head'		=>	'Moderate topic : %s',
'New subject'				=>	'New topic subject:',
'Select post'				=>	'Select post', // Label for checkbox
'Confirm post delete'		=>	'Confirm deletion of all selected posts',
'Confirm topic delete'		=>	'Confirm deletion of all selected topics',
'Confirm topic split'		=>	'Confirm splitting of all selected posts into a new topic',
'Confirm topic merge'		=>	'Confirm merging of all selected topics into one topic',
'Confirm post split'		=>	'Confirm splitting of all selected posts',
'Delete posts redirect'		=>	'Posts deleted. Redirecting …',
'Split posts redirect'		=>	'Posts split into a new topic. Redirecting …',
'No posts selected'			=>	'You must select at least one post.'

);

==> punbb-1.4.1.tar.gz: punbb-1.4.1/lang/English/misc.php <==
<?php

// Language definitions used in various scripts
$lang_misc = array(

'Mark read redirect'		=>	'All topics and forums have been marked as read.',
'Mark forum read redirect'	=>	'All topics in the specified forum have been marked as read.',

// Send e-mail
'Form e-mail disabled'		=>	'The user you are trying to send an email to has disabled form email.',
'Form e-mail errors'		=>	'<strong>Warning!</strong> The following errors must be corrected before your message can be sent:',
'No e-mail subject'			=>	'You must enter a subject.',
'No e-mail message'			=>	'You must enter a message.',
'Too long e-mail message'	=>	'Your message length is %s bytes. This exceeds the %s bytes limit.',
'Email flood'				=>	'At least %s seconds have to pass between sent emails. Please wait a while and try sending again.',
'E-mail sent redirect'		=>	'Email sent.',
'E-mail subject'			=>	'Subject',
'E-mail message'			=>	'Message',
'E-mail disclosure note'	=>	'<strong>Important!</strong> When you send an email using this form your email address will be disclosed to the recipient.',
'Write e-mail'				=>	'Compose email',
'Send forum e-mail'			=>	'Send email to %s via the forum',

// Report
'No reason'					=>	'You must enter a reason.',
'Report flood'				=>	'At least %s seconds have to pass between reports. Please wait a while and try sending again.',
'Report redirect'			=>	'Post reported.',
'Report post'				=>	'Report post',
'Reason'					=>	'Reason',
'Reason help'				=>	'Enter a short reason why you are reporting this post.',
'Too long reason'			=>	'Your report length is %s bytes. This exceeds the %s bytes limit.',
'Report errors'				=>	'<strong>Warning!</strong> The following errors must be corrected before your report can be sent:',

// Subscriptions
'Already subscribed'		=>	'You are already subscribed to this topic.',
'Subscribe redirect'		=>	'Your subscription has been added.',
'Not subscribed'			=>	'You are not subscribed to this topic.',
'Unsubscribe redirect'		=>	'Your subscription has been removed.',

// General forum and topic moderation
'Moderate forum'			=>	'Moderate forum',
'Select'					=>	'Select',	// the header of a column of checkboxes
'Move'						=>	'Move',
'Merge'						=>	'Merge',
'Open'						=>  'Open',
'Close'						=>  'Close',
'Select all'				=>	'Select all',


// Hostname lookup
'Hostname lookup'			=>	'The IP address is: %1$s<br />The host name is: %2$s<br /><br />%3$s',
'Show more users'			=>	'Show more users for this IP',

// Moderate forum
'Moderate forum head'		=>	'Moderate: %s',
'Topics'					=>	'Topics',
'Move topic'				=>	'Move topic',
'Move topics'				=>	'Move topics',
'Merge topics'				=>	'Merge topics',
'Delete topics'				=>	'Delete topics',
'Delete topic'				=>	'Delete topic',
'To new forum'				=>	'to a new forum',
'Move to'					=>	'Destination forum',
'Nowhere to move'			=>	'There are no forums into which you can move topics.',
'Leave redirect'			=>	'Leave a redirect topic in the forum from which the topic was moved.',
'Leave redirects'			=>	'Leave redirect topics in the forum from which topics were moved.',
'Leave merge redirects'		=>	'Leave redirect topics for those topics which were merged.',
'Move topic redirect'		=>	'Topic moved.',
'Move topics redirect'		=>	'Topics moved.',
'Merge topics redirect'		=>	'Topics merged.',
'Delete topic comply'		=>	'Are you sure you want to delete the selected topic?',
'Delete topics comply'		=>	'Are you sure you want to delete all the selected topics?',
'Delete topic redirect'		=>	'Topic deleted.',
'Delete topics redirect'	=>	'Topics deleted.',
'Open topic redirect'		=>	'Topic opened.',
'Open topics redirect'		=>	'Topics opened.',
'Close topic redirect'		=>	'Topic closed.',
'Close topics redirect'		=>	'Topics closed.',
'No topics selected'		=>	'You must select at least one topic.',
'Stick topic redirect'		=>	'Topic is now sticky.',
'Unstick topic redirect'	=>	'Topic no longer sticky.',
'Merge error'				=>	'You should select more than 1 topic to merge.',

// Moderate topic
'Posts'						=>	'Posts',
'Delete posts'				=>	'Delete selected posts',
'Split posts'				=>	'Split selected posts',
'Delete whole topic'		=>	'Delete whole topic',
'Moderate topic head'		=>	'Moderate topic: %s',
'New subject'				=>	'New topic subject:',
'Select post'				=>	'Select post', // Label for checkbox
'Confirm post delete'		=>	'Confirm deletion of all selected posts',
'Confirm topic delete'		=>	'Confirm deletion of all selected topics',
'Confirm topic split'		=>	'Confirm splitting of all selected posts into a new topic',
'Confirm topic merge'		=>	'Confirm merging of all selected topics into one topic',
'Confirm post split'		=>	'Confirm splitting of all selected posts',
'Delete posts redirect'		=>	'Posts deleted.',
'Split posts redirect'		=>	'Posts split into a new topic.',
'No posts selected'			=>	'You must select at least one post.'

);
